==> pytrnsys-gui-0.9a13.tar.gz: pytrnsys-gui-0.9a13/trnsysGUI/images.py <==
import trnsysGUI.imageAccessor as _ia


ImageAccessor = _ia.ImageAccessor


AIR_SOURCE_HP_PNG = _ia.ImageAccessor.createForPackageResource("images/AirSourceHP.png")
AIR_SOURCE_HP_SVG = _ia.ImageAccessor.createForPackageResource("images/AirSourceHP.svg")
BOILER_PNG = _ia.ImageAccessor.createForPackageResource("images/Boiler.png")
BOILER_SVG = _ia.ImageAccessor.createForPackageResource("images/Boiler.svg")
BVI_PNG = _ia.ImageAccessor.createForPackageResource("images/Bvi.png")
COLLECTOR_PNG = _ia.ImageAccessor.createForPackageResource("images/Collector.png")
COLLECTOR_SVG = _ia.ImageAccessor.createForPackageResource("images/Collector.svg")
CONNECTOR_PNG = _ia.ImageAccessor.createForPackageResource("images/Connector.png")
CONNECTOR_SVG = _ia.ImageAccessor.createForPackageResource("images/Connector.svg")
ELECTRIC_ROD_SVG = _ia.ImageAccessor.createForPackageResource("images/ElectricRod.svg")
EXPORT_DCK_PNG = _ia.ImageAccessor.createForPackageResource("images/exportDck.png")
EXPORT_DCK_SVG = _ia.ImageAccessor.createForPackageResource("images/exportDck.svg")
EXPORT_HYDRAULIC_CONTROL_PNG = _ia.ImageAccessor.createForPackageResource("images/exportHydraulicControl.png")
EXPORT_HYDRAULIC_CONTROL_SVG = _ia.ImageAccessor.createForPackageResource("images/exportHydraulicControl.svg")
EXPORT_HYDRAULICS_PNG = _ia.ImageAccessor.createForPackageResource("images/exportHydraulics.png")
EXPORT_HYDRAULICS_SVG = _ia.ImageAccessor.createForPackageResource("images/exportHydraulics.svg")
EXTERNAL_HX_PNG = _ia.ImageAccessor.createForPackageResource("images/ExternalHx.png")
EXTERNAL_HX_SVG = _ia.ImageAccessor.createForPackageResource("images/ExternalHx.svg")
GEAR_PNG = _ia.ImageAccessor.createForPackageResource("images/gear.png")
GEAR_SVG = _ia.ImageAccessor.createForPackageResource("images/gear.svg")
GENERIC_BLOCK_PNG = _ia.ImageAccessor.createForPackageResource("images/GenericBlock.png")
GENERIC_ITEM_PNG = _ia.ImageAccessor.createForPackageResource("images/GenericItem.png")
GROUND_SOURCE_HX_PNG = _ia.ImageAccessor.createForPackageResource("images/GroundSourceHx.png")
GROUND_SOURCE_HX_SVG = _ia.ImageAccessor.createForPackageResource("images/GroundSourceHx.svg")
HP_PNG = _ia.ImageAccessor.createForPackageResource("images/HP.png")
HP_SVG = _ia.ImageAccessor.createForPackageResource("images/HP.svg")
HP_DOUBLE_DUAL_PNG = _ia.ImageAccessor.createForPackageResource("images/HPDoubleDual.png")
HP_DOUBLE_DUAL_SVG = _ia.ImageAccessor.createForPackageResource("images/HPDoubleDual.svg")
HP_TWO_HX_PNG = _ia.ImageAccessor.createForPackageResource("images/HPTwoHx.png")
HP_TWO_HX_SVG = _ia.ImageAccessor.createForPackageResource("images/HPTwoHx.svg")
ICE_STORAGE_PNG = _ia.ImageAccessor.createForPackageResource("images/IceStorage.png")
ICE_STORAGE_SVG = _ia.ImageAccessor.createForPackageResource("images/IceStorage.svg")
ICE_STORAGE_TWO_HX_PNG = _ia.ImageAccessor.createForPackageResource("images/IceStorageTwoHx.png")
ICE_STORAGE_TWO_HX_SVG = _ia.ImageAccessor.createForPackageResource("images/IceStorageTwoHx.svg")
INBOX_PNG = _ia.ImageAccessor.createForPackageResource("images/inbox.png")
LABEL_TOGGLE_PNG = _ia.ImageAccessor.createForPackageResource("images/labelToggle.png")
OUTBOX_PNG = _ia.ImageAccessor.createForPackageResource("images/outbox.png")
PIT_STORAGE_PNG = _ia.ImageAccessor.createForPackageResource("images/PitStorage.png")
PIT_STORAGE_SVG = _ia.ImageAccessor.createForPackageResource("images/PitStorage.svg")
PROCESS_SIMULATION_PNG = _ia.ImageAccessor.createForPackageResource("images/processSimulation.png")
PROCESS_SIMULATION_SVG = _ia.ImageAccessor.createForPackageResource("images/processSimulation.svg")
PUMP_PNG = _ia.ImageAccessor.createForPackageResource("images/Pump.png")
PUMP_SVG = _ia.ImageAccessor.createForPackageResource("images/Pump.svg")
PV_PNG = _ia.ImageAccessor.createForPackageResource("images/PV.png")
PV_SVG = _ia.ImageAccessor.createForPackageResource("images/PV.svg")
RADIATOR_PNG = _ia.ImageAccessor.createForPackageResource("images/Radiator.png")
RADIATOR_SVG = _ia.ImageAccessor.createForPackageResource("images/Radiator.svg")
ROTATE_LEFT_PNG = _ia.ImageAccessor.createForPackageResource("images/rotate-left.png")
ROTATE_TO_RIGHT_PNG = _ia.ImageAccessor.createForPackageResource("images/rotate-to-right.png")
RUN_MFS_PNG = _ia.ImageAccessor.createForPackageResource("images/runMfs.png")
RUN_MFS_SVG = _ia.ImageAccessor.createForPackageResource("images/runMfs.svg")
RUN_SIMULATION_PNG = _ia.ImageAccessor.createForPackageResource("images/runSimulation.png")
RUN_SIMULATION_SVG = _ia.ImageAccessor.createForPackageResource("images/runSimulation.svg")
STORAGE_TANK_PNG = _ia.ImageAccessor.createForPackageResource("images/StorageTank.PNG")
STORAGE_TANK_SVG = _ia.ImageAccessor.createForPackageResource("images/StorageTank.svg")
TEE_PIECE_PNG = _ia.ImageAccessor.createForPackageResource("images/TeePiece.png")
TEE_PIECE_SVG = _ia.ImageAccessor.createForPackageResource("images/TeePiece.svg")
TRASH_PNG = _ia.ImageAccessor.createForPackageResource("images/trash.png")
T_VENTIL_PNG = _ia.ImageAccessor.createForPackageResource("images/TVentil.png")
T_VENTIL_SVG = _ia.ImageAccessor.createForPackageResource("images/TVentil.svg")
UPDATE_CONFIG_PNG = _ia.ImageAccessor.createForPackageResource("images/updateConfig.png")
UPDATE_CONFIG_SVG = _ia.ImageAccessor.createForPackageResource("images/updateConfig.svg")
VIS_MFS_PNG = _ia.ImageAccessor.createForPackageResource("images/visMfs.png")
VIS_MFS_SVG = _ia.ImageAccessor.createForPackageResource("images/visMfs.svg")
W_TAP_PNG = _ia.ImageAccessor.createForPackageResource("images/WTap.png")
W_TAP_SVG = _ia.ImageAccessor.createForPackageResource("images/WTap.svg")
W_TAP_MAIN_PNG = _ia.ImageAccessor.createForPackageResource("images/WTap_main.png")
W_TAP_MAIN_SVG = _ia.ImageAccessor.createForPackageResource("images/WTap_main.svg")
ZOOM_0_PNG = _ia.ImageAccessor.createForPackageResource("images/zoom-0.png")
ZOOM_IN_PNG = _ia.ImageAccessor.createForPackageResource("images/zoom-in.png")
ZOOM_OUT_PNG = _ia.ImageAccessor.createForPackageResource("images/zoom-out.png")

==> pytrnsys-gui-0.9.12.tar.gz: pytrnsys-gui-0.9.12/trnsysGUI/images.py <==
import trnsysGUI.imageAccessor as _ia


ImageAccessor = _ia.ImageAccessor


AIR_SOURCE_HP_PNG = _ia.ImageAccessor.createForPackageResource("images/AirSourceHP.png")
AIR_SOURCE_HP_SVG = _ia.ImageAccessor.createForPackageResource("images/AirSourceHP.svg")
BOILER_PNG = _ia.ImageAccessor.createForPackageResource("images/Boiler.png")
BOILER_SVG = _ia.ImageAccessor.createForPackageResource("images/Boiler.svg")
CENTRAL_RECEVIER_SVG = _ia.ImageAccessor.createForPackageResource("images/CentralReceiver.svg")
COLLECTOR_PNG = _ia.ImageAccessor.createForPackageResource("images/Collector.png")
COLLECTOR_SVG = _ia.ImageAccessor.createForPackageResource("images/Collector.svg")
CONNECTOR_PNG = _ia.ImageAccessor.createForPackageResource("images/Connector.png")
CONNECTOR_SVG = _ia.ImageAccessor.createForPackageResource("images/Connector.svg")
ELECTRIC_ROD_SVG = _ia.ImageAccessor.createForPackageResource("images/ElectricRod.svg")
EXPORT_DCK_PNG = _ia.ImageAccessor.createForPackageResource("images/exportDck.png")
EXPORT_DCK_SVG = _ia.ImageAccessor.createForPackageResource("images/exportDck.svg")
EXPORT_HYDRAULIC_CONTROL_PNG = _ia.ImageAccessor.createForPackageResource("images/exportHydraulicControl.png")
EXPORT_HYDRAULIC_CONTROL_SVG = _ia.ImageAccessor.createForPackageResource("images/exportHydraulicControl.svg")
EXPORT_HYDRAULICS_PNG = _ia.ImageAccessor.createForPackageResource("images/exportHydraulics.png")
EXPORT_HYDRAULICS_SVG = _ia.ImageAccessor.createForPackageResource("images/exportHydraulics.svg")
EXTERNAL_HX_PNG = _ia.ImageAccessor.createForPackageResource("images/ExternalHx.png")
EXTERNAL_HX_SVG = _ia.ImageAccessor.createForPackageResource("images/ExternalHx.svg")
GEAR_PNG = _ia.ImageAccessor.createForPackageResource("images/gear.png")
GEAR_SVG = _ia.ImageAccessor.createForPackageResource("images/gear.svg")
GENERIC_BLOCK_PNG = _ia.ImageAccessor.createForPackageResource("images/GenericBlock.png")
GENERIC_ITEM_PNG = _ia.ImageAccessor.createForPackageResource("images/GenericItem.png")
GROUND_SOURCE_HX_PNG = _ia.ImageAccessor.createForPackageResource("images/GroundSourceHx.png")
GROUND_SOURCE_HX_SVG = _ia.ImageAccessor.createForPackageResource("images/GroundSourceHx.svg")
HP_PNG = _ia.ImageAccessor.createForPackageResource("images/HP.png")
HP_SVG = _ia.ImageAccessor.createForPackageResource("images/HP.svg")
HP_DOUBLE_DUAL_PNG = _ia.ImageAccessor.createForPackageResource("images/HPDoubleDual.png")
HP_DOUBLE_DUAL_SVG = _ia.ImageAccessor.createForPackageResource("images/HPDoubleDual.svg")
HP_DUAL_SVG = _ia.ImageAccessor.createForPackageResource("images/HPDualSourceSingleSink.svg")
HP_TWO_HX_PNG = _ia.ImageAccessor.createForPackageResource("images/HPTwoHx.png")
HP_TWO_HX_SVG = _ia.ImageAccessor.createForPackageResource("images/HPTwoHx.svg")
ICE_STORAGE_PNG = _ia.ImageAccessor.createForPackageResource("images/IceStorage.png")
ICE_STORAGE_SVG = _ia.ImageAccessor.createForPackageResource("images/IceStorage.svg")
ICE_STORAGE_TWO_HX_PNG = _ia.ImageAccessor.createForPackageResource("images/IceStorageTwoHx.png")
ICE_STORAGE_TWO_HX_SVG = _ia.ImageAccessor.createForPackageResource("images/IceStorageTwoHx.svg")
INBOX_PNG = _ia.ImageAccessor.createForPackageResource("images/inbox.png")
LABEL_TOGGLE_PNG = _ia.ImageAccessor.createForPackageResource("images/labelToggle.png")
OUTBOX_PNG = _ia.ImageAccessor.createForPackageResource("images/outbox.png")
PIT_STORAGE_PNG = _ia.ImageAccessor.createForPackageResource("images/PitStorage.png")
PIT_STORAGE_SVG = _ia.ImageAccessor.createForPackageResource("images/PitStorage.svg")
PROCESS_SIMULATION_PNG = _ia.ImageAccessor.createForPackageResource("images/processSimulation.png")
PROCESS_SIMULATION_SVG = _ia.ImageAccessor.createForPackageResource("images/processSimulation.svg")
PT_FIELD_SVG = _ia.ImageAccessor.createForPackageResource("images/ParabolicTroughField.svg")
PUMP_PNG = _ia.ImageAccessor.createForPackageResource("images/Pump.png")
PUMP_SVG = _ia.ImageAccessor.createForPackageResource("images/Pump.svg")
PV_PNG = _ia.ImageAccessor.createForPackageResource("images/PV.png")
PV_SVG = _ia.ImageAccessor.createForPackageResource("images/PV.svg")
RADIATOR_PNG = _ia.ImageAccessor.createForPackageResource("images/Radiator.png")
RADIATOR_SVG = _ia.ImageAccessor.createForPackageResource("images/Radiator.svg")
ROTATE_LEFT_PNG = _ia.ImageAccessor.createForPackageResource("images/rotate-left.png")
ROTATE_TO_RIGHT_PNG = _ia.ImageAccessor.createForPackageResource("images/rotate-to-right.png")
RUN_MFS_PNG = _ia.ImageAccessor.createForPackageResource("images/runMfs.png")
RUN_MFS_SVG = _ia.ImageAccessor.createForPackageResource("images/runMfs.svg")
RUN_SIMULATION_PNG = _ia.ImageAccessor.createForPackageResource("images/runSimulation.png")
RUN_SIMULATION_SVG = _ia.ImageAccessor.createForPackageResource("images/runSimulation.svg")
SALT_TANK_COLD_SVG = _ia.ImageAccessor.createForPackageResource("images/SaltTankCold.svg")
SALT_TANK_HOT_SVG = _ia.ImageAccessor.createForPackageResource("images/SaltTankHot.svg")
STEAM_POWER_BLOCK_SVG = _ia.ImageAccessor.createForPackageResource("images/SteamPowerBlock.svg")
STORAGE_TANK_PNG = _ia.ImageAccessor.createForPackageResource("images/StorageTank.PNG")
STORAGE_TANK_SVG = _ia.ImageAccessor.createForPackageResource("images/StorageTank.svg")
TEE_PIECE_PNG = _ia.ImageAccessor.createForPackageResource("images/TeePiece.png")
TEE_PIECE_SVG = _ia.ImageAccessor.createForPackageResource("images/TeePiece.svg")
DP_TEE_PIECE_SVG = _ia.ImageAccessor.createForPackageResource("images/DPTeePiece.svg")
DP_TEE_PIECE_ROTATED_90 = _ia.ImageAccessor.createForPackageResource("images/DPTeePieceRotated90.svg")
DP_TEE_PIECE_ROTATED_180 = _ia.ImageAccessor.createForPackageResource("images/DPTeePieceRotated180.svg")
DP_TEE_PIECE_ROTATED_270 = _ia.ImageAccessor.createForPackageResource("images/DPTeePieceRotated270.svg")
SINGLE_DOUBLE_PIPE_CONNECTOR_SVG = _ia.ImageAccessor.createForPackageResource("images/SingleDoublePipeConnector.svg")
DOUBLE_DOUBLE_PIPE_CONNECTOR_SVG = _ia.ImageAccessor.createForPackageResource("images/DoubleDoublePipeConnector.svg")
TRASH_PNG = _ia.ImageAccessor.createForPackageResource("images/trash.png")
T_VENTIL_PNG = _ia.ImageAccessor.createForPackageResource("images/TVentil.png")
T_VENTIL_SVG = _ia.ImageAccessor.createForPackageResource("images/TVentil.svg")
UPDATE_CONFIG_PNG = _ia.ImageAccessor.createForPackageResource("images/updateConfig.png")
UPDATE_CONFIG_SVG = _ia.ImageAccessor.createForPackageResource("images/updateConfig.svg")
VIS_MFS_PNG = _ia.ImageAccessor.createForPackageResource("images/visMfs.png")
VIS_MFS_SVG = _ia.ImageAccessor.createForPackageResource("images/visMfs.svg")
W_TAP_PNG = _ia.ImageAccessor.createForPackageResource("images/WTap.png")
W_TAP_SVG = _ia.ImageAccessor.createForPackageResource("images/WTap.svg")
W_TAP_MAIN_PNG = _ia.ImageAccessor.createForPackageResource("images/WTap_main.png")
W_TAP_MAIN_SVG = _ia.ImageAccessor.createForPackageResource("images/WTap_main.svg")
SINK_SVG = _ia.ImageAccessor.createForPackageResource("images/Sink.svg")
SOURCE_SVG = _ia.ImageAccessor.createForPackageResource("images/Source.svg")
SOURCE_SINK_SVG = _ia.ImageAccessor.createForPackageResource("images/SourceAndSink.svg")
GEOTHERM_SVG = _ia.ImageAccessor.createForPackageResource("images/Geotherm.svg")
WATER_SVG = _ia.ImageAccessor.createForPackageResource("images/Water.svg")
CRYSTALIZER_SVG = _ia.ImageAccessor.createForPackageResource("images/Crystalizer.svg")
ZOOM_0_PNG = _ia.ImageAccessor.createForPackageResource("images/zoom-0.png")
ZOOM_IN_PNG = _ia.ImageAccessor.createForPackageResource("images/zoom-in.png")
ZOOM_OUT_PNG = _ia.ImageAccessor.createForPackageResource("images/zoom-out.png")
